@@ -234,7 +234,7 @@ func TestRoot_moveLateral(t *testing.T) {
 				widthLeft:  9,
 				widthRight: 11,
 				bgLeft:     0,
-				endRight:   20,
+				endRight:   22,
 			},
 		},
 	}
@@ -247,6 +247,7 @@ func TestRoot_moveLateral(t *testing.T) {
 			root.Doc.ColumnMode = false
 			root.Doc.WrapMode = false
 			root.Doc.x = tt.fields.x
+			root.prepareDraw(ctx)
 			root.moveLeftOne(ctx)
 			if root.Doc.x != tt.want.leftOne {
 				t.Errorf("leftOne got %d, want %d", root.Doc.x, tt.want.leftOne)
@@ -342,7 +343,19 @@ func TestRoot_moveColumn(t *testing.T) {
 			},
 			want: want{
 				leftOne:  7,
-				rightOne: 2,
+				rightOne: 1,
+			},
+		},
+		{
+			name: "Test MOCK_DATA3",
+			fields: fields{
+				fileName:     filepath.Join(testdata, "MOCK_DATA.csv"),
+				delimiter:    ",",
+				columnCursor: 2,
+			},
+			want: want{
+				leftOne:  1,
+				rightOne: 3,
 			},
 		},
 		{
@@ -353,7 +366,7 @@ func TestRoot_moveColumn(t *testing.T) {
 				columnCursor: 1,
 			},
 			want: want{
-				leftOne:  0,
+				leftOne:  4,
 				rightOne: 2,
 			},
 		},
@@ -362,11 +375,11 @@ func TestRoot_moveColumn(t *testing.T) {
 			fields: fields{
 				fileName:     filepath.Join(testdata, "column.txt"),
 				delimiter:    "|",
-				columnCursor: 3,
+				columnCursor: 4,
 			},
 			want: want{
-				leftOne:  2,
-				rightOne: 0,
+				leftOne:  3,
+				rightOne: 1,
 			},
 		},
 	}
@@ -381,6 +394,7 @@ func TestRoot_moveColumn(t *testing.T) {
 			root.Doc.setDelimiter(tt.fields.delimiter)
 
 			root.Doc.columnCursor = tt.fields.columnCursor
+			root.prepareDraw(ctx)
 			root.moveLeftOne(ctx)
 			if root.Doc.columnCursor != tt.want.leftOne {
 				t.Errorf("leftOne got %d, want %d", root.Doc.columnCursor, tt.want.leftOne)
